<!-- PROJECT SHIELDS -->
[![PyPI][pip-shield]](https://pypi.org/project/afip.py/)
[![Contributors][contributors-shield]](https://github.com/afipsdk/afip.py/graphs/contributors)
[![Closed issues][issues-shield]](https://github.com/afipsdk/afip.py/issues)
[![License][license-shield]](https://github.com/afipsdk/afip.py/blob/master/LICENSE.txt)


<!-- PROJECT LOGO -->
<br />
<p align="center">
  <a href="https://github.com/afipsdk/afip.py">
    <img src="https://github.com/afipsdk/afipsdk.github.io/blob/master/images/logo-colored.png" alt="Logo" width="130" height="130">
  </a>

  <h3 align="center">Afip.py</h3>

  <p align="center">
    Librería para conectarse a los Web Services de AFIP en Python
    <br />
    <a href="https://docs.afipsdk.com"><strong>Explorar documentación »</strong></a>
    <br />
    <br />
    <a href="https://github.com/afipsdk/afip.py/issues">Reportar un bug</a>
  </p>
</p>


<!-- DOCS -->
## Documentación
[Explorar documentación](https://docs.afipsdk.com)

<!-- ABOUT THE PROJECT -->
## Acerca del proyecto
Con más de 60k descargas, desde el 2017 Afip SDK es la librería elegida por los desarrolladores para integrar sus plataformas con AFIP.

Esta librería fue creada con la intención de ayudar a los programadores a usar los Web Services de AFIP sin romperse la cabeza ni perder tiempo tratando de entender la complicada documentación que AFIP provee.

<!-- CONTACT -->
### Contacto
Afip SDK - afipsdk@gmail.com

Link del proyecto: [https://github.com/afipsdk/afip.py](https://github.com/afipsdk/afip.py)


_Este software y sus desarrolladores no tienen ninguna relación con la AFIP._

<!-- MARKDOWN LINKS & IMAGES -->
[pip-shield]: https://img.shields.io/pypi/dm/afip.py.svg?logo=python&?logoColor=white
[contributors-shield]: https://img.shields.io/github/contributors/afipsdk/afip.py.svg?color=orange
[issues-shield]: https://img.shields.io/github/issues-closed-raw/afipsdk/afip.py.svg?color=blueviolet
[license-shield]: https://img.shields.io/github/license/afipsdk/afip.py.svg?color=blue
